@@ -16,12 +16,12 @@ from pywikibot.site import Namespace
 from pywikibot.textlib import removeDisabledParts
 
 
-FilePageType = TypeVar("FilePageType", bound="FilePage")
+FilePageT = TypeVar("FilePageT", bound="FilePage")
 NamespaceType = Union[int, str, Namespace]
 PageSource = Union[
     pywikibot.page.Page, pywikibot.site.BaseSite, pywikibot.page.BaseLink
 ]
-PageType = TypeVar("PageType", bound="Page")
+PageT = TypeVar("PageT", bound="Page")
 
 
 @lru_cache()
@@ -44,10 +44,7 @@ def get_redirects(
             continue
         link_pages.add(page)
         with suppress(pywikibot.exceptions.CircularRedirectError):
-            redirects = page.backlinks(
-                filter_redirects=True, namespaces=namespaces
-            )
-            link_pages.update(redirects)
+            link_pages.update(page.redirects(namespaces=namespaces))
     return frozenset(link_pages)
 
 
@@ -61,11 +58,11 @@ class Page(pywikibot.Page):
 
     @classmethod
     def from_wikilink(
-        cls: type[PageType],
+        cls: type[PageT],
         wikilink: object,
         site: pywikibot.site.BaseSite,
         default_namespace: int = 0,
-    ) -> PageType:
+    ) -> PageT:
         """
         Create a Page from a wikilink.
 
@@ -144,7 +141,7 @@ class Page(pywikibot.Page):
         text = text.strip()
         current_text = self.text  # type: ignore[has-type]
         if self.BOT_START_END.match(current_text):
-            self.text = self.BOT_START_END.sub(fr"\1\n{text}\2", current_text)
+            self.text = self.BOT_START_END.sub(rf"\1\n{text}\2", current_text)
         else:
             self.text = text
         self.save(minor=minor, botflag=botflag, **kwargs)
@@ -155,11 +152,11 @@ class FilePage(pywikibot.FilePage, Page):
 
     @classmethod
     def from_wikilink(
-        cls: type[FilePageType],
+        cls: type[FilePageT],
         wikilink: object,
         site: pywikibot.site.BaseSite,
         default_namespace: int = 6,
-    ) -> FilePageType:
+    ) -> FilePageT:
         """
         Create a FilePage from a wikilink.
 
@@ -170,11 +167,6 @@ class FilePage(pywikibot.FilePage, Page):
         """
         return super().from_wikilink(wikilink, site, default_namespace)
 
-    @property
-    def is_used(self) -> bool:
-        """Return True if the file is used, False otherwise."""
-        return len(set(self.usingPages())) > 0
-
     @property
     def megapixels(self) -> float | None:
         """
@@ -190,11 +182,13 @@ class FilePage(pywikibot.FilePage, Page):
         else:
             return height * width / 1e6 or None
 
-    def usingPages(  # noqa: N802
-        self, total: int | None = None, content: bool = False
-    ) -> Generator[Page, None, None]:
+    def using_pages(self, **kwargs: Any) -> Generator[Page, None, None]:
         """Yield pages on which the file is displayed."""
-        for page in super().usingPages(total=total, content=content):
+        count = 0
+        total = kwargs.pop("total", None)
+        for page in super().using_pages(**kwargs):
+            if total and count >= total:
+                return
             page = Page(page)
             # MediaWiki considers file redirects to be using the target flie,
             # but they are not actually using it.
@@ -204,6 +198,8 @@ class FilePage(pywikibot.FilePage, Page):
                     or not page.isRedirectPage()
                     or page.getRedirectTarget() != self
                 ):
+                    count += 1
                     yield page
             except pywikibot.exceptions.Error:  # pragma: no cover
+                count += 1
                 yield page
